packager

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Packager

type Packager struct {
	// contains filtered or unexported fields
}

Packager archives built release targets into the distribution directory. It does not build — callers are responsible for building first (e.g. via builder.Builder).

func NewPackager

func NewPackager(p project.Project) *Packager

NewPackager constructs a Packager for the given project.

func (*Packager) PackageTarget

func (p *Packager) PackageTarget(target, variantName string) error

PackageTarget archives the build output for the given target variant. The build output must already exist at the expected path under BuildDir.

func (*Packager) Setup

func (p *Packager) Setup() error

Setup creates the distribution directory.

Directories

Path Synopsis

Jump to