Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Packager ¶
type Packager struct {
// contains filtered or unexported fields
}
Packager archives built release targets into the distribution directory. It does not build — callers are responsible for building first (e.g. via builder.Builder).
func NewPackager ¶
NewPackager constructs a Packager for the given project.
func (*Packager) PackageTarget ¶
PackageTarget archives the build output for the given target variant. The build output must already exist at the expected path under BuildDir.
Click to show internal directories.
Click to hide internal directories.